@@ -3,7 +3,9 @@ from pathlib import Path
 from subprocess import run
 from edges_analysis.analysis import (
     CalibratedData,
+    RawData,
     CombinedData,
+    CombinedBinnedData,
     DayAveragedData,
     BinnedData,
     ModelData,
@@ -69,17 +71,29 @@ def beam_settings() -> Path:
 
 
 @pytest.fixture(scope="session")
-def calibrate_settings(integration_test_data: Path) -> Path:
+def raw_settings(integration_test_data: Path) -> Path:
     settings = {
         "band": "low",
+        "thermlog_file": str(integration_test_data / "thermlog_low.txt"),
+        "weather_file": str(integration_test_data / "weather.txt"),
+    }
+
+    out = integration_test_data / "raw.yaml"
+    with open(out, "w") as fl:
+        yaml.dump(settings, fl)
+
+    return out
+
+
+@pytest.fixture(scope="session")
+def calibrate_settings(integration_test_data: Path) -> Path:
+    settings = {
         "calfile": str(integration_test_data / "calfile_Rcv_2017_05.h5"),
         "s11_path": str(integration_test_data / "s11"),
         "balun_correction": True,
         "antenna_correction": False,
         "ground_correction": ":",
         "beam_file": str(integration_test_data / "feko_Haslam408_ref70.00.h5"),
-        "thermlog_file": str(integration_test_data / "thermlog_low.txt"),
-        "weather_file": str(integration_test_data / "weather.txt"),
     }
 
     out = integration_test_data / "calibrate.yaml"
@@ -90,8 +104,32 @@ def calibrate_settings(integration_test_data: Path) -> Path:
 
 
 @pytest.fixture(scope="session")
-def cal_step(
+def raw_step(
     integration_test_data: Path,
+    raw_settings: Path,
+    edges_config: dict,
+) -> Tuple[RawData, RawData]:
+    invoke(
+        cli.process,
+        [
+            "raw",
+            str(raw_settings),
+            "-i",
+            str(integration_test_data / "2016_*_00_small.acq"),
+            "-l",
+            "raw",
+        ],
+    )
+
+    return tuple(
+        read_step(fl)
+        for fl in sorted((edges_config["paths"]["field_products"] / "raw").glob("*.h5"))
+    )
+
+
+@pytest.fixture(scope="session")
+def cal_step(
+    raw_step: Tuple[RawData, RawData],
     calibrate_settings: Path,
     edges_config: dict,
     settings: Path,
@@ -102,7 +140,7 @@ def cal_step(
             "calibrate",
             str(calibrate_settings),
             "-i",
-            str(integration_test_data / "2016_*_00_small.acq"),
+            str(raw_step[0].filename.parent / "*.h5"),
             "-l",
             "calibrated",
         ],
@@ -113,16 +151,14 @@ def cal_step(
         [
             str(settings / "xrfi.yml"),
             "-i",
-            str(edges_config["paths"]["field_products"] / "calibrated/*.h5"),
+            str(raw_step[0].filename.parent / "calibrated/*.h5"),
         ],
     )
 
-    return [
+    return tuple(
         read_step(fl)
-        for fl in sorted(
-            (edges_config["paths"]["field_products"] / "calibrated").glob("*.h5")
-        )
-    ]
+        for fl in sorted((raw_step[0].filename.parent / "calibrated").glob("*.h5"))
+    )
 
 
 @pytest.fixture(scope="session")
@@ -148,6 +184,16 @@ def combo_step(model_step, settings: Path, integration_test_data: Path):
     )
 
 
+@pytest.fixture(scope="session")
+def combo_bin_step(combo_step, settings: Path, integration_test_data: Path):
+    with open(settings / "combine_bin.yml") as fl:
+        s = yaml.load(fl, Loader=yaml.FullLoader)
+
+    return CombinedBinnedData.promote(
+        combo_step, filename=integration_test_data / "combinedbinned.h5", **s
+    )
+
+
 @pytest.fixture(scope="session")
 def day_step(combo_step: CombinedData, settings: Path, integration_test_data: Path):
     with open(settings / "day_average.yml") as fl:
